@@ -70,7 +70,7 @@ class m_Ret():
     if flag == 2:
       self.txt = ipywidgets.HTML(value='<p style="text-align: left;style=font-family:Arial"><span style="color: #ff0000;">' + txt + '</span></p>')
 
-# Função principal
+# Função principal
 def visual_layer():
 
   drive_connect()
@@ -82,7 +82,7 @@ def visual_layer():
   _learn = None
   _interp = None
   
-  pass #display(ipywidgets.Image(value=open("/content/0.png", "rb").read(),format='png')) # Header
+  display(ipywidgets.Image(value=open("/content/0.png", "rb").read(),format='png')) # Header
     
   # Função para definição do Path
   def build_path(path_f):
@@ -227,7 +227,7 @@ def visual_layer():
 
     # Atividade - Exportar modelo
     with grid0.output_to(0,0):
-      pass #display(ipywidgets.Image(value=open("/content/2.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/2.png", "rb").read(),format='png', layout=l_vbox))
 
     # Atividade - Exportar modelo
     with grid0.output_to(1,0):
@@ -272,7 +272,7 @@ def visual_layer():
     grid1 = colabwidigets.Grid(12,1)
     
     with grid1.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/3.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/3.png", "rb").read(),format='png', layout=l_vbox))
 
     # Definir Path
     with grid1.output_to(1,0):
@@ -437,7 +437,7 @@ def visual_layer():
     grid2 = colabwidigets.Grid(9,1)
 
     with grid2.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/4.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/4.png", "rb").read(),format='png', layout=l_vbox))
 
     # Arquitetura, Métricas e Learner
     with grid2.output_to(1,0):
@@ -561,7 +561,7 @@ def visual_layer():
     grid3 = colabwidigets.Grid(9,1)
 
     with grid3.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/5.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/5.png", "rb").read(),format='png', layout=l_vbox))
 
     # Matriz de confusao
     with grid3.output_to(1,0):
@@ -664,7 +664,7 @@ def visual_layer():
     grid4 = colabwidigets.Grid(6,1)
 
     with grid4.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/6.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/6.png", "rb").read(),format='png', layout=l_vbox))
 
     # Unfreeze e Find lr
     with grid4.output_to(1,0):
@@ -738,7 +738,7 @@ def visual_layer():
     grid5 = colabwidigets.Grid(9,1)
 
     with grid5.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/7.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/7.png", "rb").read(),format='png', layout=l_vbox))
 
     # Matriz de confusao ft
     with grid5.output_to(1,0):
@@ -841,7 +841,7 @@ def visual_layer():
     grid6 = colabwidigets.Grid(3,1)
 
     with grid6.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/8.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/8.png", "rb").read(),format='png', layout=l_vbox))
 
     # Predicao com upload
     with grid6.output_to(1,0):
@@ -875,7 +875,7 @@ def visual_layer():
     grid7 = colabwidigets.Grid(4,1)
 
     with grid7.output_to(0,0):    
-      pass #display(ipywidgets.Image(value=open("/content/9.png", "rb").read(),format='png', layout=l_vbox))
+      display(ipywidgets.Image(value=open("/content/9.png", "rb").read(),format='png', layout=l_vbox))
 
     # Exportar modelo PKL
     with grid7.output_to(1,0):
@@ -914,7 +914,7 @@ def visual_layer():
           if Path(_dir_e_onnx).is_dir():
             try:
               _learn.model
-              _learn.model.eval();
+              _learn.model.eval()
               x = torch.randn(1, 3, 299, 299, requires_grad=False).cuda()
               torch_out = torch.onnx._export(_learn.model, x, _dir_e_onnx + 'export_model_onnx.onnx', export_params=True)
               msg_ret = m_Ret(_('Exportado para: ' + _dir_e_onnx + 'export_model_onnx.onnx com sucesso'), 1)
